==> igniteui-react-16.16.2.tgz: package/esm2015/lib/DropdownItem.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let DropdownItem = /*@__PURE__*/ (() => {
    class DropdownItem extends BaseElement {
        constructor() {
            super(...arguments);
            this.a = new WCNativeHelper();
            this.f = null;
        }
        get b() {
            return this.a;
        }
        get nativeElement() {
            return this.f;
        }
        set nativeElement(a) {
            this.f = a;
            this.a.d = this.f;
        }
        get h() {
            let ret_ = this.b.c("value");
            return ret_;
        }
        set h(a) {
            let value_ = a;
            this.b.i("value", value_);
        }
        get e() {
            let ret_ = this.b.c("selected");
            return ret_;
        }
        set e(a) {
            let value_ = a;
            this.b.i("selected", value_);
        }
        get c() {
            let ret_ = this.b.c("active");
            return ret_;
        }
        set c(a) {
            let value_ = a;
            this.b.i("active", value_);
        }
        get d() {
            let ret_ = this.b.c("disabled");
            return ret_;
        }
        set d(a) {
            let value_ = a;
            this.b.i("disabled", value_);
        }
        i() {
            this.nativeElement.connectedCallback();
        }
    }
    DropdownItem.$t = /*@__PURE__*/ markType(DropdownItem, 'DropdownItem', BaseElement.$);
    return DropdownItem;
})();

==> igniteui-react-18.5.1.tgz: package/esm2015/lib/DropdownItem.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let DropdownItem = /*@__PURE__*/ (() => {
    class DropdownItem extends BaseElement {
        constructor() {
            super(...arguments);
            this.a = new WCNativeHelper();
            this.f = null;
        }
        get b() {
            return this.a;
        }
        get nativeElement() {
            return this.f;
        }
        set nativeElement(a) {
            this.f = a;
            this.a.o = this.f;
        }
        setNativeElement(a) {
            this.nativeElement = a;
        }
        get h() {
            let ret_ = this.b.n("value");
            return ret_;
        }
        set h(a) {
            let value_ = a;
            this.b.v("value", value_);
        }
        get e() {
            let ret_ = this.b.n("selected");
            return ret_;
        }
        set e(a) {
            let value_ = a;
            this.b.v("selected", value_);
        }
        get c() {
            let ret_ = this.b.n("active");
            return ret_;
        }
        set c(a) {
            let value_ = a;
            this.b.v("active", value_);
        }
        get d() {
            let ret_ = this.b.n("disabled");
            return ret_;
        }
        set d(a) {
            let value_ = a;
            this.b.v("disabled", value_);
        }
        i() {
            this.nativeElement.connectedCallback();
        }
    }
    DropdownItem.$t = /*@__PURE__*/ markType(DropdownItem, 'DropdownItem', BaseElement.$);
    return DropdownItem;
})();
